@@ -1,5 +1,5 @@
 package Mail::DMARC::Report::Aggregate::Record::Auth_Results::SPF;
-our $VERSION = '1.20210927';
+our $VERSION = '1.20240214';
 use strict;
 
 use Carp;
@@ -27,7 +27,7 @@ sub new {
 
 sub domain {
     return $_[0]->{domain} if 1 == scalar @_;
-    return $_[0]->{domain} =  $_[1];
+    return $_[0]->{domain} =  lc $_[1];
 }
 
 sub result {
@@ -91,7 +91,7 @@ Mail::DMARC::Report::Aggregate::Record::Auth_Results::SPF - auth_results/spf sec
 
 =head1 VERSION
 
-version 1.20210927
+version 1.20240214
 
 =head1 AUTHORS
 
@@ -113,7 +113,7 @@ Marc Bradshaw <marc@marcbradshaw.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Matt Simerson.
+This software is copyright (c) 2024 by Matt Simerson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
